/*
 
 Copyright (C) 2006 NTT DATA Corporation
 
 This program is free software; you can redistribute it and/or
 Modify it under the terms of the GNU General Public License 
 as published by the Free Software Foundation, version 2.
 
 This program is distributed in the hope that it will be
 useful, but WITHOUT ANY WARRANTY; without even the implied 
 warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR 
 PURPOSE.  See the GNU General Public License for more details.
 
 */

package com.clustercontrol.monitor.run.bean;

/**
 * 文字列監視一覧のテーブル定義を定数として格納するクラス<BR>
 * 
 * @version 2.1.0
 * @since 2.1.0
 */
public class StringValueListTabelDefine {
	
	/** 順序。 */
	public static final int ORDER_NO = 0;
	
	/**
	 * 処理。
	 * 
	 * @see com.clustercontrol.bean.ProcessConstant
	 */
	public static final int PROCESS_TYPE = 1;
	
	/** 説明。 */
	public static final int DESCRIPTION = 2;
	
	/** 通知ID。 */
	public static final int VALID_FLG = 3;
	
	/** メッセージID。 */
	public static final int MESSAGE_ID = 4;
	
	/** 初期表示時ソートカラム。 */
	public static final int SORT_COLUMN_INDEX = ORDER_NO;
	
	/** 初期表示時ソートオーダー。 */
	public static final int SORT_ORDER = 1;
	
}